@@ -6,12 +6,12 @@ Business::Fixflo - Perl library for interacting with the Fixflo API
 (https://www.fixflo.com)
 
 =for html
-<a href='https://travis-ci.org/G3S/business-fixflo?branch=master'><img src='https://travis-ci.org/G3S/business-fixflo.svg?branch=master' alt='Build Status' /></a>
-<a href='https://coveralls.io/r/G3S/business-fixflo?branch=master'><img src='https://coveralls.io/repos/G3S/business-fixflo/badge.png?branch=master' alt='Coverage Status' /></a>
+<a href='https://travis-ci.org/Humanstate/business-fixflo?branch=master'><img src='https://travis-ci.org/Humanstate/business-fixflo.svg?branch=master' alt='Build Status' /></a>
+<a href='https://coveralls.io/r/Humanstate/business-fixflo?branch=master'><img src='https://coveralls.io/repos/Humanstate/business-fixflo/badge.png?branch=master' alt='Coverage Status' /></a>
 
 =head1 VERSION
 
-0.21
+0.22
 
 =head1 DESCRIPTION
 
@@ -367,7 +367,7 @@ This library is free software; you can redistribute it and/or modify it under
 the same terms as Perl itself. If you would like to contribute documentation,
 features, bug fixes, or anything else then please raise an issue / pull request:
 
-    https://github.com/G3S/business-fixflo
+    https://github.com/Humanstate/business-fixflo
 
 =cut
 
